function [t,y] = ExpMidPoint(f,y0,T,h)
%
%   NAME:
%
%  [T,Y] = EXPMIDPOINT(F,Y0,[T0 T1],H) solves the ODE y'=f(t,y) over the
%  interval [T0 T1] with y(T0) = Y0 using the explicit middle-point rule
%  with step size (at most) H.  The input argument F should be a function
%  handle taking the arguments (t,y) and returning a column vector
%  corresponding to f(t,y).
%
%   Butcher Table:
%     0  | 
%    1/2 | 1/2
%    ____|________
%        |  0   1

% Initialize variables
N = ceil((T(2)-T(1))/h); % number of steps
h = (T(2)-T(1))/N; % adjust step size to fit interval length
d = size(y0,1); % dimension of solution
t = linspace(T(1),T(2),N+1); % time grid
y = nan(d,N+1); % solution
y(:,1) = y0; % set initial value

% Compute solution
for j=1:N
  y(:,j+1) = ExpMidPointStep(% complete function call.
end

function y1 = ExpMidPointStep(f,y0,t0,h)
% Computes one step of the explicit middle-point rule
  
  % Add slopes and update here...
  k1 = ...
  k2 = ...
  y1 = ...
